@@ -237,6 +237,9 @@ class Stack:
     def reverse(self):
         return Stack(stack=list(reversed(self.stack)))
 
+    def distinct(self):
+        return list(set(self.stack))
+
     def extend(self, lst):
         if isinstance(lst, list):
             for itm in lst:
@@ -248,6 +251,7 @@ class Stack:
                 self.stack.append(item)
                 if isinstance(logger, Logger):
                     logger.debug(f'self.stack.append: {item}')
+                return True
             else:
                 if isinstance(logger, Logger):
                     logger.debug(f'self.stack.not append: {item}')
@@ -256,6 +260,7 @@ class Stack:
             self.stack.append(item)
             if isinstance(logger, Logger):
                 logger.debug(f'self.stack.append: {item}')
+            return True
 
         if isinstance(logger, Logger):
             logger.debug(f'size stack: {len(self.stack)}')
