@@ -10,7 +10,7 @@ logger = logging.getLogger(__name__)
 class User_permission(AuditModel):
     user = ForeignKeyCascade("User")
     widget = ForeignKeyCascade("Widgets_trees")
-    permission = JSONFieldIVC(default=dict)
+    permission = JSONFieldIVC()
 
     def __str__(self):
         return f"{self.user.username}: {self.widget.id_widget}"
