@@ -1,5 +1,6 @@
 import logging
 
+from django.db import transaction
 from django.forms import model_to_dict
 
 from isc_common.auth.models.user_permission import User_permission
@@ -27,7 +28,9 @@ class Widgets_treesManager(AuditManager):
 
         data = request.get_data()
         if data.get('id_widget') == '/':
-            data = data.get('children')[0]
+            children = data.get('children')
+            if isinstance(children, list) and len(children) > 0:
+                data = children[0]
 
         id_widget = data.get('id_widget')
 
@@ -88,6 +91,22 @@ class Widgets_treesManager(AuditManager):
 
         return dict()
 
+    def deleteFromRequest(self, request, removed=None, ):
+        request = DSRequest(request=request)
+        res = 0
+        tuple_ids = request.get_tuple_ids()
+        with transaction.atomic():
+            for id, mode in tuple_ids:
+                if mode == 'hide':
+                    super().filter(id=id).soft_delete()
+                    res += 1
+                elif mode == 'visible':
+                    super().filter(id=id).soft_restore()
+                else:
+                    qty, _ = super().filter(id=id).delete()
+                    res += qty
+        return res
+
     @staticmethod
     def getRecord(record):
         res = {
