@@ -21,6 +21,10 @@ class ChatData:
     message_state_new_name: Text
     message_state_readed_id: int
     message_state_readed_name: Text
+    message_state_not_readed_id: int
+    message_state_not_readed_name: Text
+    not_: int
+    message_state_not_readed_name: Text
     path: Text
     port: int
     props: int
@@ -45,6 +49,3 @@ class ChatResponseData(Dict):
     user__color: CSSColor
     user__short_name: Text
     user_id: int
-
-
-FREQUENCY_OF_POLLING_UNREAD_MESSAGES = 1000 * 60 * 3
